summaryrefslogtreecommitdiffstats
path: root/crawl-ref/source/ng-wanderer.cc
diff options
context:
space:
mode:
authorNeil Moore <neil@s-z.org>2011-10-21 18:35:54 -0400
committerNeil Moore <neil@s-z.org>2011-10-21 18:35:54 -0400
commit17133c5ab4514f52bb888758d44a06429303261d (patch)
treed14f6872afca29a51463f9ed1a6aa649220fb77d /crawl-ref/source/ng-wanderer.cc
parent3b7b1c7ec8588aa8f33753a53df3f54cec9600cd (diff)
downloadcrawl-ref-17133c5ab4514f52bb888758d44a06429303261d.tar.gz
crawl-ref-17133c5ab4514f52bb888758d44a06429303261d.zip
Fix up !healing -> curing in a few comments etc.
Diffstat (limited to 'crawl-ref/source/ng-wanderer.cc')
-rw-r--r--crawl-ref/source/ng-wanderer.cc12
1 files changed, 6 insertions, 6 deletions
diff --git a/crawl-ref/source/ng-wanderer.cc b/crawl-ref/source/ng-wanderer.cc
index a76aee7b7a..2e22507482 100644
--- a/crawl-ref/source/ng-wanderer.cc
+++ b/crawl-ref/source/ng-wanderer.cc
@@ -449,8 +449,8 @@ static void _good_potion_or_scroll(int & slot)
slot++;
}
-// Make n random attempts at identifying healing or teleportation.
-static void _healing_or_teleport(int n)
+// Make n random attempts at identifying curing or teleportation.
+static void _curing_or_teleport(int n)
{
int temp_rand = 2;
@@ -586,9 +586,9 @@ static void _wanderer_good_equipment(skill_type & skill, int & slot)
case SK_UNARMED_COMBAT:
case SK_INVOCATIONS:
{
// Random consumables: 2x attempts to ID healing/teleportation
// 1 good potion/scroll.
- _healing_or_teleport(2);
+ _curing_or_teleport(2);
_good_potion_or_scroll(slot);
break;
}
@@ -714,7 +714,7 @@ static void _wanderer_decent_equipment(skill_type & skill,
}
// Don't give a gift from the same skill twice; just default to
- // a healing potion/teleportation scroll.
+ // a curing potion/teleportation scroll.
if (gift_skills.find(skill) != gift_skills.end())
skill = SK_TRAPS_DOORS;
@@ -769,7 +769,7 @@ static void _wanderer_decent_equipment(skill_type & skill,
case SK_UNARMED_COMBAT:
case SK_INVOCATIONS:
case SK_EVOCATIONS:
- _healing_or_teleport(1);
+ _curing_or_teleport(1);
break;
}
}
@@ -586,9 +586,9 @@ static void _wanderer_good_equipment(skill_type & skill, int & slot)
case SK_INVOCATIONS:
{
- // Random consumables: 2x attempts to ID healing/teleportation
+ // Random consumables: 2x attempts to ID curing/teleportation
// 1 good potion/scroll.